@@ -19,7 +19,7 @@ class Causalml(CausalEstimator):
         # Check the backdoor variables being used
         self.logger.debug("Back-door variables used:" +
                           ",".join(self._target_estimand.get_backdoor_variables()))
-        
+
         # Add the observed confounders and one hot encode the categorical variables
         self._observed_common_causes_names = self._target_estimand.get_backdoor_variables()
         if self._observed_common_causes_names:
@@ -29,11 +29,11 @@ class Causalml(CausalEstimator):
             self._observed_common_causes = pd.get_dummies(self._observed_common_causes, drop_first=True)
         else:
             self._observed_common_causes = []
-        
+
         # Check the instrumental variables involved
         self.logger.debug("Instrumental variables used:"+
                         ",".join(self._target_estimand.instrumental_variables))
-        
+
         # Perform the same actions as the above
         self._instrumental_variable_names = self._target_estimand.instrumental_variables
         if self._instrumental_variable_names:
@@ -43,10 +43,10 @@ class Causalml(CausalEstimator):
             self._instrumental_variables = []
 
         # Check if effect modifiers are used
-        self.logger.debug("Effect Modifiers used:" + 
+        self.logger.debug("Effect Modifiers used:" +
                         ",".join(self._effect_modifier_names))
-        
-        
+
+
         # Get the class corresponding the the estimator to be used
         estimator_class = self._get_causalml_class_object(self._causalml_methodname)
         # Initialize the object
@@ -54,9 +54,9 @@ class Causalml(CausalEstimator):
         self.logger.info("INFO: Using CausalML Estimator")
         self.symbolic_estimator = self.construct_symbolic_estimator(self._target_estimand)
         self.logger.info(self.symbolic_estimator)
-        
+
     def _get_causalml_class_object(self, module_method_name, *args, **kwargs):
-        
+
         try:
             (module_name, _, class_name) = module_method_name.rpartition(".")
             estimator_module = import_module(module_name)
@@ -69,12 +69,12 @@ class Causalml(CausalEstimator):
     def _estimate_effect(self):
         X_names = self._observed_common_causes_names + \
                 self._effect_modifier_names
-        
+
         # Both the outcome and the treatment have to be 1D arrays according to the CausalML API
-        y_name = self._outcome_name 
+        y_name = self._outcome_name
         treatment_name = self._treatment_name[0] # As we have only one treatment variable
         # We want to pass 'v0' rather than ['v0'] to prevent a shape mismatch
-        
+
         func_args={
             'X':self._data[X_names],
             'y':self._data[y_name],
@@ -83,19 +83,21 @@ class Causalml(CausalEstimator):
 
         arg_names = inspect.getfullargspec(self.estimator.estimate_ate)[0]
         matched_args = {
-            arg: func_args[arg] for arg in func_args.keys() if arg in arg_names 
+            arg: func_args[arg] for arg in func_args.keys() if arg in arg_names
         }
         print(matched_args)
-        value_tuple = self.estimator.estimate_ate(**matched_args) 
+        value_tuple = self.estimator.estimate_ate(**matched_args)
 
         # For CATEs
         arg_names = inspect.getfullargspec(self.estimator.fit_predict)[0]
         matched_args = {
-            arg: func_args[arg] for arg in func_args.keys() if arg in arg_names 
+            arg: func_args[arg] for arg in func_args.keys() if arg in arg_names
         }
-        cate_estimates = self.estimator.fit_predict(**matched_args) 
+        cate_estimates = self.estimator.fit_predict(**matched_args)
 
         estimate = CausalEstimate(estimate=value_tuple[0],
+                                  control_value=self._control_value,
+                                  treatment_value=self._treatment_value,
                                   target_estimand=self._target_estimand,
                                   realized_estimand_expr=self.symbolic_estimator,
                                   cate_estimates = cate_estimates,
@@ -103,7 +105,7 @@ class Causalml(CausalEstimator):
                                   _estimator_object=self.estimator)
 
         return estimate
-        
+
 
     def construct_symbolic_estimator(self, estimand):
         expr = "b: " + ",".join(estimand.outcome_variable) + "~"
@@ -112,4 +114,4 @@ class Causalml(CausalEstimator):
         var_list = estimand.treatment_variable + estimand.get_backdoor_variables()
         expr += "+".join(var_list)
         return expr
- 
+
