@@ -76,8 +76,6 @@ class CausalGraph:
             self._graph = self.add_missing_nodes_as_common_causes(observed_node_names)
         # Adding node attributes
         self._graph = self.add_node_attributes(observed_node_names)
-        #TODO do not add it here. CausalIdentifier should call causal_graph to add an unobserved common cause if needed. This also ensures that we do not need get_common_causes in this class.
-        self._graph = self.add_unobserved_common_cause(observed_node_names)
 
     def view_graph(self, layout="dot"):
         out_filename = "causal_model.png"
@@ -270,6 +268,7 @@ class CausalGraph:
 
         blocked_by_conditioning = False
         has_unconditioned_collider = False
+
         for i in range(len(path)-2):
             if self._graph.has_edge(path[i], path[i+1]) and self._graph.has_edge(path[i+2], path[i+1]): # collider
                 collider_descendants = nx.descendants(self._graph, path[i+1])
@@ -392,7 +391,8 @@ class CausalGraph:
         """
         node1 = nodes1[0]
         node2 = nodes2[0]
-        return nx.all_simple_paths(self._graph, source=node1, target=node2)
+        # convert the outputted generator into a list
+        return [p for p in nx.all_simple_paths(self._graph, source=node1, target=node2)]
 
     def check_valid_frontdoor_set(self, nodes1, nodes2, candidate_nodes, frontdoor_paths=None):
         """Check if valid the frontdoor variables for set of treatments, nodes1 to set of outcomes, nodes2.
