@@ -1,12 +1,11 @@
-import logging
-import itertools
 import copy
+import itertools
+import logging
 
 import sympy as sp
 import sympy.stats as spstats
 
 import dowhy.utils.cli_helpers as cli
-
 from dowhy.utils.api import parse_state
 
 
@@ -24,9 +23,10 @@ class CausalIdentifier:
     NONPARAMETRIC_NDE="nonparametric-nde"
     NONPARAMETRIC_NIE="nonparametric-nie"
     MAX_BACKDOOR_ITERATIONS = 100000
+    VALID_METHOD_NAMES = {"default", "exhaustive-search"}
 
     def __init__(self, graph, estimand_type,
-            method_name = None,
+            method_name = "default",
             proceed_when_unidentifiable=False):
         self._graph = graph
         self.estimand_type = estimand_type
@@ -253,7 +253,7 @@ class CausalIdentifier:
 
         num_iterations = 0
         found_valid_adjustment_set = False
-        if self.method_name == "auto":
+        if self.method_name in CausalIdentifier.VALID_METHOD_NAMES:
             for size_candidate_set in range(len(eligible_variables), 0, -1):
                 for candidate_set in itertools.combinations(eligible_variables, size_candidate_set):
                     check = self._graph.check_valid_backdoor_set(treatment_name,
@@ -266,23 +266,13 @@ class CausalIdentifier:
                         if self._graph.all_observed(candidate_set):
                             found_valid_adjustment_set = True
                     num_iterations += 1
-                    if num_iterations > CausalIdentifier.MAX_BACKDOOR_ITERATIONS:
+                    if self.method_name == "default" and num_iterations > CausalIdentifier.MAX_BACKDOOR_ITERATIONS:
                         break
-                if found_valid_adjustment_set:
+                if self.method_name == "default" and found_valid_adjustment_set:
                     break
-        elif self.method_name == "exhaustive-search":
-            for size_candidate_set in range(1, len(eligible_variables)+1):
-                for candidate_set in itertools.combinations(eligible_variables, size_candidate_set):
-                    check = self._graph.check_valid_backdoor_set(treatment_name,
-                            outcome_name, candidate_set, backdoor_paths=backdoor_paths)
-                    self.logger.debug("Candidate backdoor set: {0}, is_dseparated: {1}, No. of paths blocked by observed_nodes: {2}".format(candidate_set, check["is_dseparated"], check["num_paths_blocked_by_observed_nodes"]))
-                    if check["is_dseparated"]:
-                        backdoor_sets.append({
-                            'backdoor_set': candidate_set,
-                            'num_paths_blocked_by_observed_nodes': check["num_paths_blocked_by_observed_nodes"]})
         else:
-            raise ValueError("Identifier method " + self.method_name + " not supported. Try 'default' or 'exhaustive-search'.")
-            #causes_t = self._graph.get_causes(self.treatment_name)
+            raise ValueError(f"Identifier method {self.method_name} not supported. Try one of the following: {CausalIdentifier.VALID_METHOD_NAMES}")
+        #causes_t = self._graph.get_causes(self.treatment_name)
         #causes_y = self._graph.get_causes(self.outcome_name, remove_edges={'sources':self.treatment_name, 'targets':self.outcome_name})
         #common_causes = list(causes_t.intersection(causes_y))
         #self.logger.info("Common causes of treatment and outcome:" + str(common_causes))
@@ -307,6 +297,8 @@ class CausalIdentifier:
 
     def build_backdoor_estimands_dict(self, treatment_name, outcome_name,
             backdoor_sets, estimands_dict, proceed_when_unidentifiable=None):
+        """Build the final dict for backdoor sets by filtering unobserved variables if needed.
+        """
         backdoor_variables_dict = {}
         if proceed_when_unidentifiable is None:
             proceed_when_unidentifiable = self._proceed_when_unidentifiable
@@ -520,9 +512,9 @@ class CausalIdentifier:
                 " then P({1}|{0},U) = P({1}|{0})"
             ).format(",".join(treatment_name), ",".join(frontdoor_variables_names)),
             "Second-stage-unconfoundedness": (
-                u"If U\N{RIGHTWARDS ARROW}{{{2}}} and U\N{RIGHTWARDS ARROW}{{{1}}}"
+                u"If U\N{RIGHTWARDS ARROW}{{{2}}} and U\N{RIGHTWARDS ARROW}{1}"
                 " then P({1}|{2}, {0}, U) = P({1}|{2}, {0})"
-            ).format(",".join(treatment_name), ",".join(outcome_name), ",".join(frontdoor_variables_names))
+            ).format(",".join(treatment_name), outcome_name, ",".join(frontdoor_variables_names))
         }
 
         estimand = {
@@ -565,9 +557,9 @@ class CausalIdentifier:
                     " then P({1}|{0},U) = P({1}|{0})"
                 ).format(",".join(treatment_name), ",".join(mediators_names)),
                 "Second-stage-unconfoundedness": (
-                    u"If U\N{RIGHTWARDS ARROW}{{{2}}} and U\N{RIGHTWARDS ARROW}{{{1}}}"
+                    u"If U\N{RIGHTWARDS ARROW}{{{2}}} and U\N{RIGHTWARDS ARROW}{1}"
                     " then P({1}|{2}, {0}, U) = P({1}|{2}, {0})"
-                ).format(",".join(treatment_name), ",".join(outcome_name), ",".join(mediators_names))
+                ).format(",".join(treatment_name), outcome_name, ",".join(mediators_names))
             }
         else:
             raise ValueError("Estimand type not supported. Supported estimand types are {0} or {1}'.".format(
@@ -620,10 +612,12 @@ class IdentifiedEstimand:
             Otherwise, return the backdoor variables for the default backdoor estimand.
         """
         if key is None:
-            if self.identifier_method.startswith("backdoor"):
+            if self.identifier_method and self.identifier_method.startswith("backdoor"):
                 return self.backdoor_variables[self.identifier_method]
-            else:
+            elif self.backdoor_variables is not None:
                 return self.backdoor_variables[self.default_backdoor_id]
+            else:
+                return []
         else:
             return self.backdoor_variables[key]
 
@@ -661,14 +655,19 @@ class IdentifiedEstimand:
                 identifier_method=copy.deepcopy(self.identifier_method)
             )
 
-    def __str__(self, only_target_estimand=False):
+    def __str__(self, only_target_estimand=False, show_all_backdoor_sets=False):
         s = "Estimand type: {0}\n".format(self.estimand_type)
         i = 1
         has_valid_backdoor = sum("backdoor" in key for key in self.estimands.keys())
         for k, v in self.estimands.items():
-            # Do not show backdoor key unless it is the only backdoor set.
-            if k == "backdoor" and has_valid_backdoor > 1:
-                continue
+            if show_all_backdoor_sets:
+                # Do not show backdoor key unless it is the only backdoor set.
+                if k == "backdoor" and has_valid_backdoor > 1:
+                    continue
+            else:
+                # Just show the default backdoor set
+                if k.startswith("backdoor") and k != "backdoor":
+                    continue
             if only_target_estimand and k != self.identifier_method:
                 continue
             s += "\n### Estimand : {0}\n".format(i)
