@@ -50,7 +50,6 @@ class CausalModel:
         :param estimand_type: the type of estimand requested (currently only "nonparametric-ate" is supported). In the future, may support other specific parametric forms of identification.
         :param proceed_when_unidentifiable: does the identification proceed by ignoring potential unobserved confounders. Binary flag.
         :param missing_nodes_as_confounders: Binary flag indicating whether variables in the dataframe that are not included in the causal graph, should be  automatically included as confounder nodes.
-        :param `**kwargs`: More optional parameters that can be passed to the causal model. Currently supported params: "logging_level" to indicate the level of logging needed. Possible values are logging.CRITICAL, logging.ERROR, logging.INFO, logging.WARNING,and logging.DEBUG. Default is logging.INFO.
         :returns: an instance of CausalModel class
 
         """
@@ -61,12 +60,6 @@ class CausalModel:
         self._estimand_type = estimand_type
         self._proceed_when_unidentifiable = proceed_when_unidentifiable
         self._missing_nodes_as_confounders = missing_nodes_as_confounders
-        if 'logging_level' in kwargs:
-            logging.basicConfig(level=kwargs['logging_level'])
-        else:
-            logging.basicConfig(level=logging.INFO)
-
-        # TODO: move the logging level argument to a json file. Tue 20 Feb 2018 06:56:27 PM DST
         self.logger = logging.getLogger(__name__)
 
         if graph is None:
@@ -127,7 +120,7 @@ class CausalModel:
         self.summary()
 
     def identify_effect(self, estimand_type=None,
-            method_name="auto", proceed_when_unidentifiable=None):
+            method_name="default", proceed_when_unidentifiable=None):
         """Identify the causal effect to be estimated, using properties of the causal graph.
 
         :param proceed_when_unidentifiable: Binary flag indicating whether identification should proceed in the presence of (potential) unobserved confounders.
@@ -165,7 +158,7 @@ class CausalModel:
             * Instrumental Variables: "iv.instrumental_variable"
             * Regression Discontinuity: "iv.regression_discontinuity"
 
-        In addition, you can directly call any of the EconML estimation methods. The convention is "backdoor.econml.path-to-estimator-class". For example, for the double machine learning estimator ("DMLCateEstimator" class) that is located inside "dml" module of EconML, you can use the method name, "backdoor.econml.dml.DMLCateEstimator". CausalML estimators can also be called. See `this demo notebook <https://microsoft.github.io/dowhy/example_notebooks/dowhy-conditional-treatment-effects.html>`_.
+        In addition, you can directly call any of the EconML estimation methods. The convention is "backdoor.econml.path-to-estimator-class". For example, for the double machine learning estimator ("DML" class) that is located inside "dml" module of EconML, you can use the method name, "backdoor.econml.dml.DML". CausalML estimators can also be called. See `this demo notebook <https://microsoft.github.io/dowhy/example_notebooks/dowhy-conditional-treatment-effects.html>`_.
 
 
         :param identified_estimand: a probability expression
@@ -218,7 +211,9 @@ class CausalModel:
         # Check if estimator's target estimand is identified
         if identified_estimand.estimands[identifier_name] is None:
             self.logger.warning("No valid identified estimand available.")
-            estimate = CausalEstimate(None, None, None)
+            estimate = CausalEstimate(None, None, None,
+                                  control_value=control_value,
+                                  treatment_value=treatment_value)
         else:
             causal_estimator = causal_estimator_class(
                 self._data,
@@ -235,6 +230,8 @@ class CausalModel:
             )
             estimate = causal_estimator.estimate_effect()
             # Store parameters inside estimate object for refutation methods
+            # TODO: This add_params needs to move to the estimator class
+            # inside estimate_effect and estimate_conditional_effect
             estimate.add_params(
                 estimand_type=identified_estimand.estimand_type,
                 estimator_class=causal_estimator_class,
@@ -274,7 +271,7 @@ class CausalModel:
         # Check if estimator's target estimand is identified
         if identified_estimand.estimands[identifier_name] is None:
             self.logger.warning("No valid identified estimand for using instrumental variables method")
-            estimate = CausalEstimate(None, None, None)
+            estimate = CausalEstimate(None, None, None, None, None)
         else:
             causal_estimator = causal_estimator_class(
                 self._data,
