@@ -14,18 +14,39 @@ from sklearn.neighbors import KNeighborsRegressor
 from sklearn.svm import SVR
 from sklearn.ensemble import RandomForestRegressor
 from sklearn.neural_network import MLPRegressor
+from sklearn.model_selection import train_test_split
+
+from dowhy.causal_refuters.add_unobserved_common_cause import AddUnobservedCommonCause
 
 TestFraction = namedtuple('TestFraction', ['base','other'])
 
 class DummyOutcomeRefuter(CausalRefuter):
-    """Refute an estimate by replacing the outcome with a randomly generated variable.
+    """Refute an estimate by replacing the outcome with a simulated variable
+    for which the true causal effect is known.
 
-    This allows us to have a well defined effect of the treatment on the outcome.
+    In the simplest case, the dummy outcome is an independent, randomly
+    generated variable. By definition, the true causal effect should be zero.
 
-    1. We find f(W) for a fixed value of t
-    2. For all the other values of t. We obtain the value of dummy outcome as:
+    More generally, the dummy outcome uses the observed relationship between
+    confounders and outcome (conditional on treatment) to create a more
+    realistic outcome for which the treatment effect is known to be zero. If
+    the goal is to simulate a dummy outcome with a non-zero true causal effect,
+    then we can add an arbitrary function h(t) to the dummy outcome's
+    generation process and then the causal effect becomes h(t=1)-h(t=0).
+
+    Note that this general procedure only works for the backdoor criterion.
+
+    1. We find f(W) for a each value of treatment. That is, keeping the treatment
+    constant, we fit a predictor to estimate the effect of confounders W on
+    outcome y. Note that since f(W) simply defines a new DGP for the simulated
+    outcome, it need not be the correct structural equation from W to y.
+    2. We obtain the value of dummy outcome as:
        ``y_dummy = h(t) + f(W)``
 
+    To prevent overfitting, we fit f(W) for one value of T and then use it to
+    generate data for other values of t. Future support for identification
+    based on instrumental variable and mediation.
+
     ::
 
         If we originally started out with
@@ -34,7 +55,7 @@ class DummyOutcomeRefuter(CausalRefuter):
             /    \\
             t --->y
 
-        On estimating,
+        On estimating the following with constant t,
         y_dummy = f(W)
 
                W
@@ -171,6 +192,8 @@ class DummyOutcomeRefuter(CausalRefuter):
     # The Default split for the number of data points that fall into the training and validation sets
     DEFAULT_TEST_FRACTION = [TestFraction(0.5, 0.5)]
 
+    DEFAULT_NEW_DATA_WITH_UNOBSERVED_CONFOUNDING = None
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -180,18 +203,15 @@ class DummyOutcomeRefuter(CausalRefuter):
         self._bucket_size_scale_factor = kwargs.pop("bucket_size_scale_factor", DummyOutcomeRefuter.DEFAULT_BUCKET_SCALE_FACTOR)
         self._min_data_point_threshold = kwargs.pop("min_data_point_threshold", DummyOutcomeRefuter.MIN_DATA_POINT_THRESHOLD)
         self._test_fraction = kwargs.pop("_test_fraction", DummyOutcomeRefuter.DEFAULT_TEST_FRACTION)
+        self._unobserved_confounder_values = kwargs.pop("unobserved_confounder_values", DummyOutcomeRefuter.DEFAULT_NEW_DATA_WITH_UNOBSERVED_CONFOUNDING)
         required_variables = kwargs.pop("required_variables", True)
 
         if required_variables is False:
             raise ValueError("The value of required_variables cannot be False")
 
         self._chosen_variables = self.choose_variables(required_variables)
-
-        if 'logging_level' in kwargs:
-            logging.basicConfig(level=kwargs['logging_level'])
-        else:
-            logging.basicConfig(level=logging.INFO)
-
+        # Assuming that outcome is one-dimensional
+        self._outcome_name_str = self._outcome_name[0]
         self.logger = logging.getLogger(__name__)
 
     def refute_estimate(self):
@@ -217,6 +237,7 @@ class DummyOutcomeRefuter(CausalRefuter):
         # The rationale behind ordering of the loops is the fact that we induce randomness everytime we create the
         # Train and the Validation Datasets. Thus, we run the simulation loop followed by the training and the validation
         # loops. Thus, we can get different values everytime we get the estimator.
+
         for _ in range( self._num_simulations ):
             estimates = []
 
@@ -226,12 +247,19 @@ class DummyOutcomeRefuter(CausalRefuter):
                 if self._test_fraction != DummyOutcomeRefuter.DEFAULT_TEST_FRACTION:
                     self.logger.warning("'test_fraction' is not applicable as there is no base treatment value.")
 
+                # Adding an unobserved confounder if provided by the user
+                if self._unobserved_confounder_values is not None:
+                    self._data['simulated'] = self._unobserved_confounder_values
+                    self._chosen_variables.append('simulated')
                 # We set X_train = 0 and outcome_train to be 0
                 validation_df = self._data
                 X_train = None
                 outcome_train = None
-                X_validation = validation_df[self._chosen_variables].values
-                outcome_validation = validation_df['y'].values
+                X_validation_df = validation_df[self._chosen_variables]
+
+
+                X_validation = X_validation_df.values
+                outcome_validation = validation_df[self._outcome_name_str].values
 
                 # Get the final outcome, after running through all the values in the transformation list
                 outcome_validation = self.process_data(X_train, outcome_train, X_validation, outcome_validation, self._transformation_list)
@@ -243,12 +271,17 @@ class DummyOutcomeRefuter(CausalRefuter):
                     causal_effect_map[None] = self._true_causal_effect( validation_df[ self._treatment_name[0] ] )
 
                 outcome_validation += causal_effect_map[None]
+
+
                 new_data = validation_df.assign(dummy_outcome=outcome_validation)
+
+
                 new_estimator = CausalEstimator.get_estimator_object(new_data, identified_estimand, self._estimate)
                 new_effect = new_estimator.estimate_effect()
                 estimates.append(new_effect.value)
 
             else:
+
                 groups = self.preprocess_data_by_treatment()
                 group_count = 0
 
@@ -260,9 +293,10 @@ class DummyOutcomeRefuter(CausalRefuter):
                     train_set = set( [ tuple(line) for line in base_train.values ] )
                     total_set = set( [ tuple(line) for line in groups.get_group(key_train).values ] )
                     base_validation = pd.DataFrame( list( total_set.difference(train_set) ), columns=base_train.columns )
+                    X_train_df = base_train[self._chosen_variables]
 
-                    X_train = base_train[self._chosen_variables].values
-                    outcome_train = base_train['y'].values
+                    X_train = X_train_df.values
+                    outcome_train = base_train[self._outcome_name_str].values
 
                     validation_df = []
                     transformation_list = self._transformation_list
@@ -273,8 +307,10 @@ class DummyOutcomeRefuter(CausalRefuter):
                             validation_df.append(groups.get_group(key_validation).sample(frac=self._test_fraction[group_count].other))
 
                     validation_df = pd.concat(validation_df)
-                    X_validation = validation_df[self._chosen_variables].values
-                    outcome_validation = validation_df['y'].values
+                    X_validation_df = validation_df[self._chosen_variables]
+
+                    X_validation = X_validation_df.values
+                    outcome_validation = validation_df[self._outcome_name_str].values
 
                     # If the number of data points is too few, run the default transformation: [("zero",""),("noise", {'std_dev':1} )]
                     if X_train.shape[0] <= self._min_data_point_threshold:
@@ -294,14 +330,18 @@ class DummyOutcomeRefuter(CausalRefuter):
 
                     # Add h(t) to f(W) to get the dummy outcome
                     outcome_validation += causal_effect_map[key_train]
+
                     new_data = validation_df.assign(dummy_outcome=outcome_validation)
                     new_estimator = CausalEstimator.get_estimator_object(new_data, identified_estimand, self._estimate)
                     new_effect = new_estimator.estimate_effect()
+
                     estimates.append(new_effect.value)
                     group_count += 1
 
+
             simulation_results.append(estimates)
 
+
         # We convert to ndarray for ease in indexing
         # The data is of the form
         # sim1: cat1 cat2 ... catn
@@ -316,6 +356,8 @@ class DummyOutcomeRefuter(CausalRefuter):
 
             dummy_estimate = CausalEstimate(
                     estimate = causal_effect_map[None],
+                    control_value = self._estimate.control_value,
+                    treatment_value=self._estimate.treatment_value,
                     target_estimand =self._estimate.target_estimand,
                     realized_estimand_expr=self._estimate.realized_estimand_expr)
 
@@ -330,6 +372,7 @@ class DummyOutcomeRefuter(CausalRefuter):
             )
 
             refute.add_refuter(self)
+
             refute_list.append(refute)
 
         else:
@@ -338,8 +381,10 @@ class DummyOutcomeRefuter(CausalRefuter):
             # Iterating through the refutation for each category
             for train_category in range(simulation_results.shape[1]):
                 dummy_estimate = CausalEstimate(
-                    estimate = causal_effect_list[train_category],
-                    target_estimand =self._estimate.target_estimand,
+                    estimate=causal_effect_list[train_category],
+                    control_value=self._estimate.control_value,
+                    treatment_value=self._estimate.treatment_value,
+                    target_estimand=self._estimate.target_estimand,
                     realized_estimand_expr=self._estimate.realized_estimand_expr)
 
                 refute = CausalRefutation(
@@ -354,6 +399,8 @@ class DummyOutcomeRefuter(CausalRefuter):
 
                 refute.add_refuter(self)
                 refute_list.append(refute)
+
+
         return refute_list
 
     def process_data(self, X_train, outcome_train, X_validation, outcome_validation, transformation_list):
@@ -431,6 +478,11 @@ class DummyOutcomeRefuter(CausalRefuter):
         """
         assert len(self._treatment_name) == 1, "At present, DoWhy supports a simgle treatment variable"
 
+
+        if self._unobserved_confounder_values is not None:
+            self._data['simulated'] = self._unobserved_confounder_values
+            self._chosen_variables.append('simulated')
+
         treatment_variable_name = self._treatment_name[0] # As we only have a single treatment
         variable_type = self._data[treatment_variable_name].dtypes
 
@@ -473,6 +525,7 @@ class DummyOutcomeRefuter(CausalRefuter):
         estimator = self._get_regressor_object(action, **func_args)
         X = X_train
         y = outcome
+
         estimator = estimator.fit(X, y)
 
         return estimator.predict
@@ -512,8 +565,8 @@ class DummyOutcomeRefuter(CausalRefuter):
         '''
         if permute_fraction == 1:
             outcome = pd.DataFrame(outcome)
-            outcome.columns = ['y']
-            return outcome['y'].sample(frac=1).values
+            outcome.columns = [self._outcome_name_str]
+            return outcome[self._outcome_name_str].sample(frac=1).values
         elif permute_fraction < 1:
             permute_fraction /= 2 # We do this as every swap leads to two changes
             changes = np.where( np.random.uniform(0,1,outcome.shape[0]) <= permute_fraction )[0] # As this is tuple containing a single element (array[...])
@@ -529,13 +582,12 @@ class DummyOutcomeRefuter(CausalRefuter):
             raise ValueError("The value of permute_fraction is {}. Which is greater than 1.".format(permute_fraction))
 
     def noise(self, outcome, std_dev):
-        """ Add white noise with mean 0 and standard deviation = std_dev
+        """
+        Add white noise with mean 0 and standard deviation = std_dev
 
-        :param 'outcome': np.ndarray
+        - 'outcome': np.ndarray
         The outcome variable, to which the white noise is added.
-        :param 'std_dev': float
+        - 'std_dev': float
         The standard deviation of the white noise.
-
-        :returns: input with added noise.
         """
         return outcome + np.random.normal(scale=std_dev,size=outcome.shape[0])
