@@ -8,13 +8,15 @@ class TestRegressionDiscontinuityEstimator(object):
     @pytest.mark.parametrize(["error_tolerance", "Estimator",
         "num_common_causes", "num_instruments",
         "num_effect_modifiers", "num_treatments",
-        "treatment_is_binary", "outcome_is_binary"],
-                             [(0.2, RegressionDiscontinuityEstimator, [1], [1,], [0], [1,], [True,], [False,]),])
+        "treatment_is_binary", "outcome_is_binary", "identifier_method"],
+                             [(0.2, RegressionDiscontinuityEstimator, [1], [1,], [0], [1,], [True,], [False,], "iv"),])
     def test_average_treatment_effect(self, error_tolerance, Estimator,
             num_common_causes, num_instruments, num_effect_modifiers,
-            num_treatments, treatment_is_binary, outcome_is_binary
+            num_treatments, treatment_is_binary, outcome_is_binary,
+            identifier_method
             ):
-        estimator_tester = TestEstimator(error_tolerance, Estimator)
+        estimator_tester = TestEstimator(error_tolerance, Estimator,
+                identifier_method=identifier_method)
         estimator_tester.average_treatment_effect_testsuite(
                 num_common_causes=num_common_causes,
                 num_instruments = num_instruments,
